import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/border" as Border
import "../common/Margins.js" as Margins

Item
{
	objectName: "PasswordArea"
	Localizer { id:tr; scope:"ParentalControl" }
	property variant commonFontStyles: Fonts.Common{}
	property variant context: MainWindow.GetSubViewModel("ParentalControl")
	property string error: ""
	id: passwordArea

	anchors.fill: parent
	
	function setActiveFocus()
	{
    	settingsPassword.forceActiveFocus();
	}
	
    Widgets.StandardCaptionText
	{
		id: header
		y: 100
		anchors.horizontalCenter: parent.horizontalCenter
		text: tr.Localize("PasswordAreaSet")
	}

	Widgets.KeyNavigation
	{
		id: keyNavigations

		Component.onCompleted:
		{
			var items = [
				parentalControlPassword,
				settingsPassword,
				exitPassword,
				uninstallPassword,
				createPasswordButton];
			focusedItems = items;
		}
	}
	Keys.onUpPressed: keyNavigations.onSetPrevious(event)
	Keys.onDownPressed: keyNavigations.onSetNext(event)

	Column
	{
		id: passwordAreas
		anchors.top: header.bottom
        anchors.topMargin: Margins.verticalCaptionToCommonText + 4
		anchors.horizontalCenter: parent.horizontalCenter

		spacing: 10

		Widgets.CheckBox
		{
			id: parentalControlPassword
			objectName:	"parentalControlPassword"
			maxWidth: passwordArea.width
			enabled: false
			checked: true
			text: tr.Localize("ParentalControlPasswordArea")
            horizontalMargin: 5
            anchors.left: parent.left
		}
		
		Widgets.CheckBox
		{
			id: settingsPassword
			objectName:	"settingsPassword"
			maxWidth: passwordArea.width
			checked: true
			text: tr.Localize("SettingsPasswordArea")
            horizontalMargin: 5
            anchors.left: parent.left
		}
		
		Widgets.CheckBox
		{
			id: exitPassword
			objectName:	"exitPassword"
			maxWidth: passwordArea.width
			checked: true
			text: tr.Localize("ExitPasswordArea")
            horizontalMargin: 5
            anchors.left: parent.left
		}
		
		Widgets.CheckBox
		{
			id: uninstallPassword
			objectName:	"uninstallPassword"
			maxWidth: passwordArea.width
			checked: true
			text: tr.Localize("UninstallPasswordArea")
            horizontalMargin: 5
            anchors.left: parent.left
		}
	}
	
    Widgets.GrayButton
	{
		id: createPasswordButton
		objectName: "CreatePasswordButton"
		setAsDefaultButton: true
		anchors.top: passwordAreas.bottom
        anchors.topMargin: 20
		anchors.horizontalCenter: parent.horizontalCenter
		text: tr.Localize("CreatePassword")

		onClicked:
		{
			context.PasswordSet.ShouldAskPasswordParentalControl = parentalControlPassword.checked
			context.PasswordSet.ShouldAskPasswordSettings = settingsPassword.checked
			context.PasswordSet.ShouldAskPasswordExit = exitPassword.checked
			context.PasswordSet.ShouldAskPasswordUninstall = uninstallPassword.checked
			if (context.PasswordSet.SetupPassword())
			{
				error = ""
				context.PasswordEnter.Password = context.PasswordSet.Password
				context.PasswordEnter.VerifyPassword()
				context.PasswordEnter.ResetPassword()
			}
			else
			{
				error = tr.Localize("PasswordNotComplex")
			}		
		}
	}
	
	Text
	{
		anchors.top: createPasswordButton.bottom
		anchors.topMargin: 20
		anchors.horizontalCenter: parent.horizontalCenter
		text: error
		font: commonFontStyles.standardCommonTextFont
		color: "red"
	}
}
