import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts

Item
{
    id: aboutCredits

    property string text

    Timer
    {
        id: scrollableTimer
        running: !creditsView.moving && aboutCredits.visible
        repeat: true
        interval: 24
        onTriggered:
        {
            creditsView.contentY += 1;
        }
    }

    Flickable
    {
        id: creditsView

        property double previousContentY: 0

        anchors.fill: parent
        anchors.margins: 0

        clip: true

        boundsBehavior: Flickable.DragAndOvershootBounds

        interactive: true

        contentHeight: creditsText.height

        onContentYChanged:
        {
            if(contentY < 0)
            {
                contentY = contentHeight - height + contentY
            }
            else if (contentY > contentHeight - height)
            {
                contentY = contentY - contentHeight + height
            }
        }

        Text
        {
            id: creditsText
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: paintedHeight

            textFormat: Text.RichText

            property int emptyLinesNumber: creditsView.height * dpiScaler.factor / (font.pixelSize * 1.2)

            horizontalAlignment: Text.AlignHCenter

            text: aboutCredits.text
            wrapMode: Text.WordWrap
            font: aboutFontStyles.standardAboutFont

            onLinkActivated:
            {
                easterEggImage.visible = true
            }
            Component.onCompleted:
            {
                var emptyFields = "";
                for(var i = 0; i < emptyLinesNumber; i++)
                {
                    emptyFields += "<br>"
                }
                text = emptyFields + text + emptyFields;
            }
        }
    }

    RawImage
    {
        id: easterEggImage
        objectName: "easterEggImage"

        visible: false

        width: 96
        height: 166

        x: parent.width - width - 10

        anchors.verticalCenter: parent.verticalCenter

        image: context.easterEggImage

        MouseArea
        {
            id: closeArea

            enabled: easterEggImage.visible

            anchors.fill: parent

            onClicked: {
                easterEggImage.visible = false
            }
        }
    }
}
