import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/ProductTypeHelper.js" as ProductTypeHelper

Widgets.PageFrame
{
	property variant context: MainWindow.activationWizard
	
	Localizer { id:tr; scope:"LicenseManager" }

	signal showHelp;

	function getPage(id)
	{
		switch(id)
		{
			case "ActivationPage_UserChoice": 	return activationPageEdition;
			case "ActivationPage_Error": 		return activationPageFailed;
			case "ActivationPage_Success": 		return activationPageSucceed;
			case "ActivationPage_Processing": 	return activationPageProcessing;
			case "ActivationPage_NoConnection":	return activationPageNoConnection;
			case "ActivationPage_OtherProductDueActivation":	return activationPageOtherProductDueActivation;
			case "ActivationPage_ReservedCode":					return activationPageReservedCode;
			case "ActivationPage_HasLicense":					return activationPageHasLicense;
			case "ActivationPage_OtherProductDueReserve":		return activationPageOtherProductDueReserve;
			case "ActivationPage_FormDownloaded":				return activationPageRegistration;
			case "ActivationPage_SubscriptionReplace":			return activationPageSubscriptionReplace;
			case "ActivationPage_InProductPurchasing":			return activationPagePurchasing;
		}

		console.log(objectName + "::unknown page: " + id);
		return NULL;
	}

	property variant page: context.CurrentPageId
	onPageChanged:
	{	
		var newPage = getPage(EnumHelper.getKey(context, "CurrentPageId"))
		
		
		if(currentPage == newPage)			
			return;
			
		if(currentPage)
			currentPage.visible = false;
				
		currentPage = newPage;
		currentPage.visible = true;
		
		console.log(objectName + "::onPageChanged: " + currentPage.objectName);

		hasBanner = !currentPage.wholePageArea;
	}

	id: wizard
	objectName: "activationWizard"

	onAnimationCompleted:
	{
		if (currentPage)
			currentPage.animationCompleted();
	}

	function getHelpId()
	{
		if (currentPage && (typeof currentPage.getHelpId == 'function'))
			return currentPage.getHelpId();
		return 0;
	}

	property variant fontStyles:			Fonts.LicenseFonts{}
	property variant standartFontStyles:	Fonts.Common{}
	property variant currentPage

	property alias headerText:				headerText.text

	backButtonVisible:		wizard.currentPage.backButtonVisible
	backButtonEnabled:		context.IsBackButtonEnabled
	backButtonText:			(wizard.currentPage && wizard.currentPage.backButtonText) ? wizard.currentPage.backButtonText : tr.Localize("BackButton")

	nextButtonVisible:		wizard.currentPage.nextButtonVisible
	nextButtonEnabled:		wizard.currentPage.nextButtonEnabled
	nextButtonText:			(wizard.currentPage && wizard.currentPage.nextButtonText) ? wizard.currentPage.nextButtonText : tr.Localize("NextButton")

	cancelButtonVisible:	wizard.currentPage.cancelButtonVisible
	cancelButtonEnabled:	context.IsCancelButtonEnabled
	cancelButtonText:		(wizard.currentPage && wizard.currentPage.cancelButtonText) ? wizard.currentPage.cancelButtonText : tr.Localize("Cancel")

	helpButtonVisible:		wizard.currentPage ? wizard.currentPage.helpButtonVisible : true

	function getTitle()
	{
		var key = "ActivationWizard_Activation_Title";

		switch (EnumHelper.getKey(context, "ActivationType"))
		{
		case "AddLicense":
			key = "ActivationWizard_AddToReserve_Title";
			break;
		case "SubscriptionUpdate":
			key = "ActivationWizard_SubscriptionUpdate_Title";
			break;
		case "CheckReserveCode":
			key = "ActivationWizard_CheckReserveCode_Title";
			break;
		case "InProductPurchasing":
			key = "ActivationWizard_Purchasing";
			break;
		default:
			return tr.Localize(key, {"ProductNameFull":ProductTypeHelper.getProductNameFull(tr, context, !Global.isRelease)})
			break;
		}
		return tr.Localize(key);
	}

	windowDescriptionText:	getTitle()

	Connections {onHelp:		if (wizard.currentPage) showHelp();}
	Connections {onClose: 		context.Cancel();}
	Connections {onBack: 		context.Back();}
	Connections {onNext:		{ wizard.currentPage.onNext(); context.Next();}}
	

	ListModel{id: listPages}

	Item
	{
		id: workingArea
		objectName: "workingArea"

        property int topGap:	29
        property int bottomGap:	43 /* boottom border */
        property int leftGap:	hasBanner ? 174 : 10
        property int rightGap:	10 /* right border */

		anchors.left: parent.left
		anchors.leftMargin:leftGap
		anchors.top: parent.top
		anchors.topMargin:topGap
		width:	parent.width - leftGap - rightGap
		height: parent.height - topGap - bottomGap


		Column
		{
			id:	header
			clip: true
			visible: hasBanner

			anchors.left:parent.left
			anchors.right:parent.right
			anchors.top: parent.top

			Item { width: parent.width; height: 30 }
			Widgets.StandardCaptionText
			{
				id: headerText
				objectName: "headerText"

                property int marginWidth: 30
				anchors.left:	parent.left; anchors.leftMargin: marginWidth
				anchors.right:	parent.right; anchors.rightMargin: marginWidth

				text:	wizard.currentPage ? wizard.currentPage.headerString : ""
				wrapMode: Text.Wrap
			}
			Item { width: parent.width; height: 20 }
		}

		Rectangle
		{
			id: workingAreaSplitter
			anchors.left: parent.left
			anchors.leftMargin: 0
			anchors.right: parent.right
			anchors.rightMargin: 0
			anchors.top:	header.bottom
			height:			1
			color:			"#cccccc"
			visible: header.visible
		}

		Item
		{
			width:	parent.width
			anchors.top:	header.visible ? workingAreaSplitter.bottom : workingArea.top
			anchors.bottom: workingArea.bottom
			clip: true
			objectName: "pagesGroup"

			Item
			{
				id:			pagesWorkingArea
				objectName: "pagesWorkingArea"
				property int marginWidth:	hasBanner ? 30 : 0
				anchors.fill:				parent
				anchors.leftMargin:			marginWidth
				anchors.rightMargin:		marginWidth
				anchors.topMargin:			marginWidth
				anchors.bottomMargin:		marginWidth

				ActivationPageEdition		{id: activationPageEdition		;  context:wizard.context }
				ActivationPageHasLicense	{id: activationPageHasLicense	; context:wizard.context  }
				ActivationPageProcessing	{id: activationPageProcessing	; context:wizard.context  }
				ActivationPageSucceed		{id: activationPageSucceed		; context:wizard.context  }
				ActivationPageFailed		{id: activationPageFailed		; context:wizard.context  }
				ActivationPageNoConnection	{id: activationPageNoConnection	; context:wizard.context  }
				ActivationPageRegistration	{id: activationPageRegistration	; context:wizard.context  }
				ActivationPageReservedCode	{id: activationPageReservedCode	; context:wizard.context  }

				ActivationPageSubscriptionReplace		{id: activationPageSubscriptionReplace	; context:wizard.context  }

				ActivationPageOtherProductDueActivation	{id: activationPageOtherProductDueActivation; context:wizard.context  }
				ActivationPageOtherProductDueReserve	{id: activationPageOtherProductDueReserve	; context:wizard.context  }

				ActivationPagePurchasing	{id: activationPagePurchasing	; context:wizard.context  }
			}
		}
	}
}
