import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/Common.js" as Common
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/Margins.js" as Margins
import "../common/DateTime.js" as DateTime

Rectangle
{
    id:page
    Localizer { id:tr; scope:"LicenseManager" }
    objectName: "notActivatedPage"
    property variant model : MainWindow.licenseManager
    property variant commonFontStyles: Fonts.Common{}
	property int tabOrder: 1

    function getButtonIcon(buttonIcon)
    {
        var map = {
           0 :"", //"NoIcon"
           1 :"../images/license/ico_buy_16_gray.png", //"BuyIcon"
           2 :"../images/license/BackToKAV_ico.png", //"RollbackIcon"
           3 :"../images/license/ico_support_16_gray.png", //"SupportIcon"
           4 :"../images/license/ico_download_file_16_gray.png", //"DownloadIcon"
           5 :"../images/license/ico_remove_code_16_gray.png"}; //"TrashIcon"
        return map[buttonIcon];
    }

    Column
    {
        anchors.centerIn:parent
        width:400
        objectName: "column"

        function getSubscriptionOkHeaderDescription()
        {
            return (page.model.licenseProperties.shouldShowSubscriptionRemainingDays ?
				tr.Localize("SubscriptionRemainingDaysCount", {"LicenseRemainingDaysCount" : page.model.licenseProperties.licenseRemainingDaysCount}) : tr.Localize("SubscriptionActivated") );
        }
		function getActiveLicenseBlockHeader()
		{
			if(page.model.activeLicenseBlockUsesLNCS)
				return page.model.activeLicenseBlockHeaderLNCS;
			return tr.Localize(page.model.activeLicenseBlockHeaderKey, {
                    "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
					"SubscriptionOkHeaderDescription" : getSubscriptionOkHeaderDescription()
				});
		}
        Widgets.StandardCaptionText
        {
            id: title
            anchors.horizontalCenter:parent.horizontalCenter
            text: parent.getActiveLicenseBlockHeader()
        }
        Item { height: Margins.verticalCaptionToCommonText; width: parent.width; }

		function getFunctionalityDisabledAfterGrace()
		{
			switch (page.model.licenseProperties.licenseType)
			{
			case "LicenseTypeSubscriptionProtection":
				return tr.Localize("FunctionalityDisabledForExpiredSubscriptionProtection");
			case "LicenseTypeSubscription":
				return tr.Localize("FunctionalityDisabledForExpiredSubscription");
			default:
				return "";
			}
		}
		        
		function getActiveLicenseBlockText()
		{
			if(page.model.activeLicenseBlockUsesLNCS)
				return page.model.activeLicenseBlockTextLNCS;
			return tr.Localize(page.model.activeLicenseBlockTextKey, {
				"FunctionalityLevelDescription" : tr.Localize(page.model.licenseProperties.protectionLevelDescription) + tr.Localize(page.model.updaterLevelDescription),
				"LicenseRemainingDaysCount" : page.model.licenseProperties.licenseRemainingDaysCount,
                "LicensingStatusTrialRemain" : page.model.licenseProperties.licenseRemainingDaysCount ?
                                tr.Localize("LicenseRemain", {"LicenseRemainingDaysCount" : page.model.licenseProperties.licenseRemainingDaysCount}) :
                                tr.Localize("LicenseEndsToday"),
				"PreinstalledCode" : page.model.licenseProperties.preinstalledCode,
				"FunctionalityDisabledAfterGrace" : getFunctionalityDisabledAfterGrace(),
				"StateOkSubscriptionText" : tr.Localize(page.model.licenseProperties.stateOkSubscriptionText, {
                                "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate)
                                })
			});
		}
        Text
        {
            id: description
            width:parent.width
            anchors.horizontalCenter:parent.horizontalCenter
            text: parent.getActiveLicenseBlockText()
            font:commonFontStyles.standardCommonTextFont
            wrapMode: Text.WordWrap
            horizontalAlignment:Text.AlignHCenter
            visible: text != ""
            lineHeight: Margins.commonTextLineHeight
        }
        Item { height: Margins.verticalCommonTextToWidget; width: parent.width; }
        Row
        {
            spacing:8
            anchors.horizontalCenter:parent.horizontalCenter
            objectName: "row"

            Repeater
            {
				objectName: "repeater"
                model: page.model.ActiveLicenseBlockButtonList;
                Widgets.GrayButton
                {
					id: grayButton
					objectName: model.modelData.objectName
					function prepareText()
					{
						if(model.modelData.shouldLocalize == undefined || !model.modelData.shouldLocalize)
							return model.modelData.name;
						return tr.Localize(model.modelData.name);
					}
                    text: prepareText();
                    iconImage:page.getButtonIcon(model.modelData.icon);
                    maxWidth: 300
                    onClicked:
                    {
                        if(model.modelData.action != undefined)
                            model.modelData.action.Invoke(Common.buildPath(parent)+"."+grayButton.objectName);
                        else if(model.modelData.panel != "") ; //TODO: panel navigation

                    }
                }
            }
        }
    }
}
