import QtQuick 1.1
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/fonts" as Fonts
import "../common/HelpMapper.js" as HelpMapper

MigrationBasePage
{
    objectName: "migrationAppListPage"
    property variant commonFontStyles: Fonts.Common{}
    helpButtonVisible: true
    
    property variant curPage: context.CurrentPage
    property string page: ""

	function getHelpId()
	{
        return (EnumHelper.getKey(context, "CurrentPage") == "SearchManualRemovalApplications")
                ? HelpMapper.MigrationSearchManualRemovalApplicationsHelpId
                : HelpMapper.MigrationAppListPageHelpId;
	}

    onCurPageChanged:
    {
		page = EnumHelper.getKey(context, "CurrentPage")
    }

    Text
    {
        anchors.top:parent.top;
        anchors.left:parent.left;
        anchors.right:parent.right;
        id: desc
        text: getPageDescription()
        wrapMode: Text.WordWrap
    }

    ListView
    {
        id:list
        anchors.left: parent.left;
        anchors.right: parent.right;
        anchors.top:desc.bottom;
        anchors.bottom:addRemove.visible ? addRemove.top : parent.bottom;
        anchors.margins:20
        spacing: 4
        model: context.ApplicationsList
        delegate:itemDelegate

        Rectangle
        {
            border.color: "black";
            anchors.fill:parent
            anchors.margins: -5
            color: "transparent"
            radius: 3
        }
    }

    Component
    {
        id: itemDelegate
        Text
        {
            text: model.modelData.name;
            font: commonFontStyles.standardCommonTextFont
        }
    }

    Widgets.GrayButton
    {
		objectName: "OpenRemoveProgramsPanel"
        anchors.margins:8
        anchors.right: parent.right;
        anchors.bottom: parent.bottom;
        id:addRemove
        text: tr.Localize("OpenRemoveProgramsPanel");
        onClicked:
        {
			context.UninstallApplicationsAction.Invoke()
        }
        visible: page == "ManualRemovalApplications";
    }
}
