import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "ApplicationControl"

    property string helpUrl: "$HelpURLSettingsAppCtl"
    property int helpId: HelpMapper.ApplicationControlSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings,"ApplicationControl")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "ApplicationControlSettings" }

    Column
    {
        objectName: "Column"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "GeneralApplicationControl"

            body: Column
            {
                objectName: "GeneralApplicationControlSection"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    objectName: "UseApplicationControl"
                    anchors.left: parent.left
                    text: tr.Localize("UseApplicationControl");
                    isBold: true
                    target: context
                    property: "enableApplicationControl"
                }
            }
        }

        Item
        {
            enabled: context.enableApplicationControl
            objectName: "SettingsRow"
            width: parent.width
            height: childrenRect.height
            anchors.left: parent.left

            SettingsCommon.SettingsStandardText
            {
                id: rulesText
                anchors.top: parent.top
                anchors.topMargin: 8
                anchors.left: parent.left
                anchors.right: applicationsButton.left
                anchors.rightMargin: 10
                text: tr.Localize("SettingsDescription")
                wrapMode: Text.Wrap
                color: parent.enabled ? "black" : "grey"
            }

            SettingsCommon.SettingsButton
            {
                id: applicationsButton
                objectName: "ApplicationsButton"
                anchors.top: rulesText.top
                anchors.right: identityProtectionButton.left
                anchors.rightMargin: 5
                text: tr.Localize("Applications")
                onClicked: context.showApplicationsDialog()
            }

            SettingsCommon.SettingsButton
            {
                id: identityProtectionButton
                objectName: "IdentityProtectionButton"
                anchors.top: rulesText.top
                anchors.right: parent.right
                text: tr.Localize("IdentityProtection")
                onClicked: context.showIdentityProtectionDialog()
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ApplicationsRestrictionSection"
            enabled: context.enableApplicationControl
            name: tr.Localize("ApplicationsRestrictionSection");
            body: Item
            {
                objectName: "ColumnWrapper"
                width: parent.width
                height: childrenRect.height
                Column
                {
                    objectName: "Column"
                    spacing: Margins.settingsInnerSpacing
                    width: parent.width

                    Column
                    {
                        width: parent.width
                        objectName: "CheckboxRules"
                        spacing: Margins.settingsCheckboxSpacing
                        SettingsCommon.CheckBox
                        {
                            objectName: "LoadRulesFromKSN"
                            target: context
                            property: "useKsn"
                            anchors.left: parent.left
                            text: tr.Localize("LoadRulesFromKSN")
                        }

                        SettingsCommon.CheckBox
                        {
                            objectName: "UpdateRulesFromKSN"
                            target: context
                            property: "updateKsn"
                            text: tr.Localize("UpdateRulesFromKSN")
                            anchors.left: parent.left
                            anchors.leftMargin: 18
                            enabled: parent.enabled && context.useKsn
                        }

                        SettingsCommon.CheckBox
                        {
                            objectName: "TrustSignedApps"
                            anchors.left: parent.left
                            target: context
                            property: "trustSigned"
                            text: tr.Localize("TrustSignedApps")
                        }
                    }

                    Column
                    {
                        id: radioRules
                        objectName: "RadioRules"
                        spacing: Margins.settingsRadioSpacing
                        width: parent.width

                        SettingsCommon.SettingsStandardText
                        {
                            text: tr.Localize("ForUnknownApps")
                            wrapMode: Text.Wrap
                            anchors.left: parent.left
                            color: parent.enabled ? "black" : "grey"
                        }

                        SettingsCommon.BoolRadioGroup
                        {
                            id: autoSelectGroup

                            target: context
                            property: "autoSelectGroup"
                            objectName: "AutoSelectGroup"
                            anchors.left: parent.left
                            trueDescription: tr.Localize("SelectGroupAutomatically")
                            falseDescription: tr.Localize("UseHeuristicToDefineGroup")
                            trueFirst: false
                        }

                        Component.onCompleted:
                        {
                            defaultGroup.lastRadio = autoSelectGroup.getRadio(2)
                        }
                    }

                    Item
                    {
                        id: analyzeTimeoutItem
                        objectName: "AnalyzeTimeout"
                        enabled: parent.enabled && !context.autoSelectGroup
                        height: analyzeTimeoutSpin.height
                        width: parent.width

                        property string text: tr.Localize("AnalyzeTimeout")
                        Widgets.HotKeyParser
                        {
                            id: hotKeyParser
                            text: analyzeTimeoutItem.text
                        }
                        Widgets.HotKey
                        {
                            text: hotKeyParser.hotKeyText
                            onPressed: analyzeTimeoutSpin.setActiveFocus();
                        }
		
                        SettingsCommon.SettingsStandardText
                        {
                            anchors.left: parent.left
                            id: analyzeTimeout
                            text: hotKeyParser.textToShow
                            anchors.verticalCenter: parent.verticalCenter
                            color: parent.enabled ? "black" : "grey"
                        }

                        Widgets.IntSpinEdit
                        {
                            id: analyzeTimeoutSpin
                            objectName: "Spin"
                            anchors.left: analyzeTimeout.right
                            anchors.leftMargin: Margins.settingsBeforeSpinEdit + 10
                            anchors.verticalCenter: analyzeTimeout.verticalCenter
                            target: context
                            property: "analyzeTimeout"
                            minValue: 5
                            maxValue: 60
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            text: tr.Localize("Sec")
                            anchors.left: analyzeTimeoutSpin.right
                            anchors.leftMargin: Margins.settingsAfterSpinEdit
                            anchors.verticalCenter: analyzeTimeoutSpin.verticalCenter
                            color: parent.enabled ? "black" : "grey"
                        }
                    }
                }

                SettingsCommon.EnumCombo
                {
                    id: defaultGroup
                    property Item lastRadio: autoSelectGroup.getRadio(2);
                    objectName: "DefaultGroup"

                    anchors.left: parent.left
                    anchors.leftMargin: lastRadio.width
                    y: radioRules.y + autoSelectGroup.y + autoSelectGroup.height/2

                    enabled: parent.enabled && context.autoSelectGroup
                    target: context
                    property: "defaultGruop"
                    localizationObject: tr

                    Component.onCompleted:
                    {
                        console.log(lastRadio.width)
                    }
                }
            }
        }
        SettingsCommon.SettingsSection
        {
            objectName: "AdditionalSection"
            enabled: context.enableApplicationControl
            name: tr.Localize("AdditionalSection");
            body: Column
            {
                objectName: "Column"
                width: parent.width

                Item
                {
                    objectName: "DeleteRulesRow"
                    height: deleteRulesSpin.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: deleteRules
                        objectName: "DeleteRules"
                        target: context
                        property: "deleteRules"
                        text: tr.Localize("DeleteRules")
                        height: deleteRulesSpin.height
                        maxWidth: 1000000
                        anchors.left: parent.left
                        anchors.verticalCenter: parent.verticalCenter
                    }

                    Widgets.IntSpinEdit
                    {
                        id: deleteRulesSpin
                        objectName: "Spin"
                        enabled: parent.enabled && context.deleteRules
                        anchors.left: deleteRules.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: deleteRules.verticalCenter
                        anchors.verticalCenterOffset: 2
                        target: context
                        property: "deleteTimeout"
                        minValue: 1
                        maxValue: 90
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        text: tr.Localize("Days")
                        anchors.left: deleteRulesSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: deleteRulesSpin.verticalCenter
                        color: parent.enabled && context.deleteRules ? "black" : "grey"
                    }
                }
            }
        }
    }
}
