import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "ImMonitor"

    property int helpId: HelpMapper.ImMonitorSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "ImMonitor")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "ImMonitorSettings" }
    Column
    {
        objectName: "Column"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "GeneralImMonitor"
            body: Column {
                objectName: "GeneralImMonitorSection"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    id: useGamingProfile
                    objectName: "UseGamingProfile"
                    text: tr.Localize("UseIMMonitor");
                    isBold: true
                    target: context
                    property: "enableImMonitor"
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ProtectionScopeSection"
            name: tr.Localize("ProtectionScope")
            enabled: context.enableImMonitor

            body: Column
            {
                width: parent.width
                SettingsCommon.BoolRadioGroup
                {
                    objectName: "CheckIncomingMessagesOnly"
                    target: context
                    property: "checkIncomingMessagesOnly"
                    trueFirst: false
                    trueDescription: tr.Localize("CheckIncomingMessagesOnly")
                    falseDescription: tr.Localize("CheckIncomingAndOutgoingMessages")
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ScanMethodsSection"
            name: tr.Localize("ScanMethods")
            enabled: context.enableImMonitor
            body: Column
            {
                objectName: "ScanMethods"
                width: parent.width
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    objectName: "UseSuspiciousURLList"
                    text: tr.Localize("UseSuspiciousURLList");
                    target: context
                    property: "useSuspiciousURLList"
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "UseAntiphishing"
                    text: tr.Localize("UseAntiphishings");
                    target: context
                    property: "useAntiphishing"
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "HeuristicAnalysis"
                    text: tr.Localize("HeuristicAnalysis");
                    target: context
                    property: "heuristicAnalysis"
                    anchors.left: parent.left
                }

                SettingsCommon.EnumSlider
                {
                    objectName: "HeuristicLevel"
                    enabled: parent.enabled && context.heuristicAnalysis
                    localizer: tr
                    target: context
                    property: "heuristicLevel"
                    hasMarks1: true
                    hasMarks2: true
                    anchors.left: parent.left
                    anchors.leftMargin: 7
                    anchors.right: parent.right
                    anchors.rightMargin: 7
                }
            }
        }
    }
}
