import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "SettingsMargins.js" as Margins


SettingsSection
{
    id: section

    property variant context
    property bool showPostpone: context.showPostpone

    objectName: "ThreatDetectionActionSection"

    Localizer { id: tr; scope: "SettingsThreatDetectionAction" }

    name: tr.Localize("ActionOnThreatDetection")

    body:
    Item {

        objectName: "MainWrapper"
        width: parent.width
        height: childrenRect.height
        Column
        {
            spacing: Margins.settingsSectionInnerSpacing
            objectName: "MainColumn"
            width: parent.width

            EnumRadioGroup
            {
                id: threatGroup
                objectName: "ThreatGroup"

                anchors.left: parent.left
                target: context
                property: "action"
                localizer: tr

                function isRadioButtonVisible(enumName)
                {
                    return context.showPostponeWhenInteractionEnabled || enumName != "ThreatDetectActionPostpone"
                }

                function getLocalizerKey(enumName)
                {
                    var key = enumName
                    switch (enumName)
                    {
                        case "ThreatDetectActionAsk":
                            return enumName + (context.interactionDisabled ? "Non" : "") + "Interactive";
                        default:
                            return enumName;
                    }
                }

                Component.onCompleted: text1.lastRadio = text1.getLastRadio()

            }

            Column
            {
                objectName: "CheckBoxesColumn"
                width: parent.width
                enabled: parent.enabled && (EnumExtension.GetKey(context, "action") + (context.action ? "" : "")) == "ThreatDetectActionDontAsk"
                anchors
                {
                    left: parent.left
                    leftMargin: 20
                }
                spacing: Margins.settingsCheckboxSpacing

                CheckBox
                {
                    objectName: "TryDesinfect"
                    target: section.context
                    property: "tryDisinfect"
                    text: tr.Localize("TryDisinfect")
                    anchors.left: parent.left
                }

                CheckBox
                {
                    objectName: "TryDelete"
                    target: section.context
                    property: "tryDelete"
                    text: tr.Localize(section.context.tryDisinfect ? "TryDeleteIfDisinfectionFails" : "TryDelete")
                    anchors.left: parent.left
                }
            }
        }

        SettingsStandardText
        {
            id: text1

            property string currentText: getCurrentText()
            property Item lastRadio

            function getCurrentText()
            {
                if (context.tryDisinfect || context.tryDelete)
                    return "ThreatDetect" + (context.tryDisinfect ? "Disinfect" : "") + (context.tryDelete ? "Delete" : "");
                else
                    return "ThreatDetect" + (showPostpone ? "WithPostpone" : "WithoutPostpone");
            }

            function getLastRadio()
            {
                return threatGroup.itemAt(2);
            }

            anchors.left: parent.left
            anchors.leftMargin: lastRadio.width - 5
            y: lastRadio.y + (height - lastRadio.height)/2 + 1
            font.bold: true
            text: tr.Localize(currentText)
            color:
            {
                var value = context.action
                var result = (EnumExtension.GetKey(context, "action") == "ThreatDetectActionDontAsk") ? "black" : "gray"
                return value ? result : result;
            }
        }
    }
}
