import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/EnumHelper.js" as EnumHelper
import "../common/ProductTypeHelper.js" as ProductTypeHelper

Border.BorderedContent
{
	objectName: "checkHostsPage"
	content: checkHosts
	Localizer { id:tr; scope:"CheckHosts" }
	
	Widgets.PageFrame
	{
		id:	checkHosts
		objectName: "checkHosts"
		property variant context: CheckHosts
		property variant fontStyles: Fonts.Common{}

		property variant defaultButtonManager: defaultButtonManagerId
		Widgets.DefaultButtonManager{id: defaultButtonManagerId}
		Keys.forwardTo: defaultButtonManagerId
		focus: true

		Keys.onEscapePressed: Window.Close();

		LayoutMirroring.enabled: Window.Mirror
		LayoutMirroring.childrenInherit: true

		windowDescriptionText: tr.Localize("CheckHostsPageHeader", {"ProductName":ProductTypeHelper.getProductName(tr, context)})
		helpButtonVisible: false
		cancelButtonText: tr.Localize("FinishButton")
		cancelButtonIsDefault: !cureHostsButton.setAsDefaultButton
		clip: true

		onCancel: Window.Close();
		onClose: Window.Close();

		Item
		{
			id: workingArea
			objectName: "workingArea"
			anchors.fill: parent
			clip: true

			anchors.topMargin: 29
			anchors.leftMargin: 164 /* banner width */  + 10 /*left border*/
			anchors.bottomMargin: 43
			anchors.rightMargin: 10

			Column
			{
				objectName: "column"
				anchors.fill: parent
				anchors.topMargin:		40
				anchors.leftMargin:		40
				anchors.rightMargin:	40
				clip: true
				spacing:		10

				Widgets.StandardCaptionText
				{
					id: headerText
					anchors.left: parent.left
					anchors.right: parent.right
					text: tr.Localize("CheckHostsPageHeaderText")
				}

				Rectangle
				{
					anchors.left: parent.left
					anchors.right: parent.right
					height: 30
					color: "white"
				}

				Text
				{
					id: infoText
					anchors.left: parent.left
					anchors.right: parent.right
					text: tr.Localize("CheckHostsPageInfoText")
					wrapMode: Text.Wrap
					font: checkHosts.fontStyles.standardCommonTextFont
				}
				Text
				{
					id: listLabel
					anchors.left: parent.left
					anchors.right: parent.right
					text: tr.Localize("CheckHostsPageListLabel")
					wrapMode: Text.Wrap
					font: checkHosts.fontStyles.standardCommonTextFont
				}
				Rectangle
				{
					anchors.left: parent.left; anchors.leftMargin: 1
					anchors.right: parent.right; anchors.rightMargin: 2;
					height: 130
					color: "white"
					border.color: "gray"
					ListView
					{
						anchors.fill: parent;
						anchors.margins: 10;
						model: checkHosts.context.Hosts
						delegate: Text
						{
							text: checkHosts.context.Hosts[index];
							anchors.left: parent.left
							horizontalAlignment: Text.AlignLeft
							color: "gray"
						}
					}
				}
				Widgets.Button
				{
					id:			cureHostsButton
					setAsDefaultButton: visible && enabled
					objectName: "cureHostsButton"
					text:			tr.Localize("CheckHostsCureHostsButton")
					textfont:		checkHosts.fontStyles.standardCommonTextFont
					backgroundImage:	"../images/widgets/gre_normal.png"
					pressedImage:		"../images/widgets/gre_pressed.png"
					horizontalMargin:	15
					verticalMargin:		8
					anchors.left: parent.left

					onClicked: checkHosts.context.CureHosts();
				}
			}
		}
	}
}
