import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/Common.js" as Common
import "SupportMargins.js" as Margins

Item
{
    id: supportSendTroublesDialog
    objectName: "SupportSendTroublesDialog"

    signal filesList
    signal monitoring;
    signal main;

    property variant contextSupport: SupportWindow
    property variant context: contextSupport.sendReport
    property bool sendFlag: false
    property int questionOpenTime: 600

    property bool sendState: context.sendTroublesState ? EnumHelper.getKey(context, "sendTroublesState") !== "SendStateDone"
                                                         && EnumHelper.getKey(context, "sendTroublesState") !== "SendStateError"
                                                       : EnumHelper.getKey(context, "sendTroublesState") !== "SendStateDone"
                                                         && EnumHelper.getKey(context, "sendTroublesState") !== "SendStateError"
    state: "normalState"

    Widgets.DPIScaler { changeHeight: true }

    onVisibleChanged:
    {
        if (visible)
            context.RefreshFiles()
    }

    BorderImage
    {
        id: questionRect
        objectName: "QuestionRect"

        anchors.horizontalCenter: sendReportSupportPanel.horizontalCenter
        source: "../common/images/support/supp_rep_bg.png"
        border {top: 2; left: 7; right: 7; bottom: 9}

        width: parent.width / 2
        height: 140
        z: 3

        Widgets.DPIScaler { changeHeight: true }

        Item
        {
            id: questionBaseItem
            objectName: "QuestionBaseItem"
            anchors.fill: parent

            Widgets.DPIScaler { changeHeight: true }

            Column
            {
                id: srfQuestionColumn
                objectName: "SrfQuestionColumn"
                anchors.fill: parent
                anchors.topMargin: 23
                spacing: 10

                Widgets.DPIScaler { changeHeight: true }

                Text
                {
                    id: srfNumberQuestionText
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.leftMargin: 20

                    text: tr.Localize("SRFNumber")
                    horizontalAlignment: Text.AlignLeft
                    font: commonFontStyles.standardCommonTextFontBold

                    Widgets.DPIScaler { changeSize: true }
                }

                Widgets.EditBox
                {
                    id: srfNumberEditBox
                    objectName: "SRFEditBox"

                    anchors.left: parent.left
                    anchors.right: parent.right

                    anchors.leftMargin: 20
                    anchors.rightMargin: 20

                    target: context
                    property: "srfNumber"
                    enabled: !sendState

                    Widgets.DPIScaler { changeHeight: true }
                }
                Item
                {
                    id: okCancelButtonsArea
                    objectName: "OkCancelButtonsArea"
                    anchors.left: parent.left
                    anchors.right: parent.right
                    height: okButton.height

                    Widgets.GrayButton
                    {
                        id: okButton
                        objectName: "OkButton"
                        text: tr.Localize("ConfirmButton")
                        anchors.top: parent.top
                        anchors.right: cancelButton.left
                        anchors.rightMargin: 10

                        enabled: srfNumberEditBox.text.length > 0

                        minWidth: parent.width / 3

                        onClicked:
                        {
                            context.SendFiles();
                            sendFlag = true;
                        }
                        Widgets.DPIScaler { changeHeight: true }
                    }
                    Widgets.GrayButton
                    {
                        id: cancelButton
                        objectName: "CancelButton"
                        text: tr.Localize("CancelButton")
                        anchors.top: parent.top
                        anchors.right: parent.right
                        anchors.rightMargin: 20

                        minWidth: parent.width  / 3

                        onClicked:
                        {
                            supportSendTroublesDialog.state = "saveToFileQuestionState";
                        }
                        Widgets.DPIScaler { changeSize: true }
                    }
                }
            }


            Column
            {
                id: saveToFileColumn
                objectName: "SaveToFileColumn"
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.leftMargin: 20
                anchors.rightMargin: 20
                anchors.topMargin: 30
                anchors.bottomMargin: 15
                spacing: 10
                visible: false

                Text
                {
                    id: saveToFileQuestionText
                    anchors.left: parent.left
                    anchors.right: parent.right

                    text: tr.Localize("saveToFileQuestion")
                    horizontalAlignment: Text.AlignHCenter
                    wrapMode: Text.WordWrap
                    font: commonFontStyles.standardCommonTextFontBold
                }

                Row
                {
                    id: yesNoButtonsArea
                    objectName: "YesNoButtonsArea"
                    anchors.horizontalCenter: parent.horizontalCenter
                    spacing: 10

                    Widgets.GrayButton
                    {
                        id: yesButton
                        objectName: "YesButton"
                        text: tr.Localize("Yes")

                        minWidth: parent.width / 3

                        Widgets.DPIScaler { changeHeight: true }

                        onClicked:
                        {
                            context.OpenFileDialog();
                            supportSendTroublesDialog.state = "normalState";
                        }
                    }
                    Widgets.GrayButton
                    {
                        id: noButton
                        objectName: "NoButton"
                        text: tr.Localize("No")

                        minWidth: parent.width / 3

                        Widgets.DPIScaler { changeHeight: true }

                        onClicked:
                        {
                            supportSendTroublesDialog.state = "normalState";
                        }
                    }
                }
            }
        }

        states:
        [
            State
            {
                name: "hidden"
                PropertyChanges {target: questionRect; y: sendReportSupportPanel.height - questionRect.height - 1}
            },
            State
            {
                name: "visible"
                PropertyChanges {target: questionRect; y: sendReportSupportPanel.height - 1}
            }
        ]

        transitions:
            Transition
            {
                NumberAnimation
                {
                    properties: "y"
                    duration: 600;
                }
            }
    }

    Rectangle
    {
        color: "white"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: sendReportSupportPanel.bottom
        z: 4
    }

    SupportPanel
    {
        id: sendReportSupportPanel
        objectName: "SupportGatheredDataPanel"
        canHome: true;
        caption: tr.Localize("ReportSending")
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        z: 4
        onHome:
        {
            supportSendTroublesDialog.main()
        }
        onBack:
        {
            supportSendTroublesDialog.monitoring()
        }

        Widgets.CaptionButton
        {
            id: sendReportButton
            objectName: "SendReportButton"
            text: tr.Localize("Send")
            minWidth: 90
            setAsDefaultButton: true

            enabled: (context.isAnalysisDataToSend || context.isSystemInfoToSend)
                     && !sendState && supportSendTroublesDialog.state == "normalState"

            onClicked:
            {
                supportSendTroublesDialog.state = "srfQuestionState";
            }

            Widgets.DPIScaler { changeSize: true }
        }
    }

    Rectangle
    {
        id: smoothRect

        color: "white"
        opacity: 0
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: sendReportSupportPanel.bottom
        anchors.bottom: parent.bottom
        z: 2

        Widgets.DPIScaler { changeHeight: true }

        states:
        [
            State
            {
                name: "hidden"
                PropertyChanges {target: smoothRect; opacity: 0}
            },
            State
            {
                name: "visible"
                PropertyChanges {target: smoothRect; opacity: 0.6}
            }
        ]

        transitions:
            Transition
            {
                NumberAnimation
                {
                    properties: "opacity"
                    duration: supportSendTroublesDialog.questionOpenTime;
                    easing.type: Easing.InOutQuad
                }
            }
    }

    Rectangle
    {
        id: backgroundRect
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: sendReportSupportPanel.bottom
        anchors.bottom: parent.bottom
        color: "white"

        Column
        {
            id: sendReportColumn
            anchors.fill: parent
            anchors.topMargin: 25
            z: 1

            Widgets.DPIScaler { changeHeight: true }

            Column
            {
                id: sendReportWorkAreaColumn
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: Margins.leftMargin
                anchors.rightMargin: 40
                spacing: 12

                Widgets.DPIScaler { changeHeight: true }

                Text
                {
                    id: bodyTitle
                    text: tr.Localize("ReportSendingComment")
                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft
                }


                Widgets.CheckBox
                {
                    id: systemInfoCheckBox
                    anchors.left: parent.left
                    anchors.right: parent.right

                    text: tr.Localize("SystemInfo")
                    target: context
                    property: "isSystemInfoToSend"
                    textfont: commonFontStyles.standardCommonTextFont
                    enabled: !sendState
                }


                Row
                {
                    id: analysisDataRow
                    width: parent.width
                    spacing: -5

                    Widgets.DPIScaler { changeHeight: true }

                    Widgets.CheckBox
                    {
                        id: gatheredDataCheckBox
                        text: tr.Localize("GatheredData")
                        enabled: !sendState

                        textfont: commonFontStyles.standardCommonTextFont
                        target: context
                        property: "isAnalysisDataToSend"
                    }

                    Widgets.Hyperlink
                    {
                        property int denominator: Common.getShortFileSizeString(context.filesToSendSize);
                        enabled: context.isAnalysisDataToSend && !sendState
                        text: "(" + tr.Localize("GatheredDataList") + " - " + (context.filesToSendSize / Math.pow(1024, denominator)).toFixed(2)
                              + " " + Common.getFileSizeSuffix(denominator) + ")"
                        anchors.verticalCenter: gatheredDataCheckBox.verticalCenter

                        color: context.isAnalysisDataToSend ? "#5495df" : "grey"
                        onClicked:
                        {
                            filesList();
                        }
                    }
                }

                Text
                {
                    id: sendCommentText

                    anchors.left: parent.left
                    anchors.right: parent.right

                    text: tr.Localize("SendComment")

                    font: commonFontStyles.standardCommonTextFont
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Text.AlignLeft

                    Widgets.DPIScaler { changeSize: true }

                    Widgets.ClickableForLinksInText
                    {
                        onLinkActivated: context.ShowDataAgreement()
                    }
                }
            }

            Behavior on opacity
            {
                NumberAnimation
                {
                    duration: supportSendTroublesDialog.questionOpenTime;
                    easing.type: Easing.InOutQuad
                }
            }
        }

        Item
        {
            id: statusIndicator

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -30
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width

            opacity: sendState ? 1 : 0

            Behavior on opacity
            {
                NumberAnimation
                {
                    duration: supportSendTroublesDialog.questionOpenTime;
                    easing.type: Easing.InOutQuad
                }
            }

            Widgets.Loading48
            {
                id: loadingProgress
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Row
            {
                anchors.top: loadingProgress.bottom
                anchors.topMargin: 10
                anchors.horizontalCenter: parent.horizontalCenter

                Text
                {
                    id: statusMessage
                    text: context.sendTroublesState ? tr.Localize(EnumHelper.getKey(context, "sendTroublesState"))
                                                    : tr.Localize(EnumHelper.getKey(context, "sendTroublesState"));
                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft
                }

                Text
                {
                    id: progressText
                    text: context.currentProgress + "%";
                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft
                }
            }

            Widgets.DPIScaler { changeHeight: true }

            states:
            [
                State
                {
                    name: "hidden"
                    PropertyChanges {target: smoothRect; opacity: 0}
                },
                State
                {
                    name: "visible"
                    PropertyChanges {target: smoothRect; opacity: 1}
                }
            ]

            transitions:
                Transition
                {
                    NumberAnimation
                    {
                        properties: "opacity"
                        duration: supportSendTroublesDialog.questionOpenTime;
                        easing.type: Easing.InOutQuad
                    }
                }
        }

        Item
        {
            id: resultIndicator

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -30
            anchors.horizontalCenter: parent.horizontalCenter

            opacity: supportSendTroublesDialog.state == "sendState" && !sendState ? 1 : 0

            Image
            {
                id: sign
                anchors.horizontalCenter: parent.horizontalCenter

                source: EnumHelper.getKey(context, "sendTroublesState") === "SendStateDone" ? "../common/images/ico_info_48.png"
                                                                                            :   (EnumHelper.getKey(context, "errorCode") === "Canceled" ? "../common/images/ico_warning_48.png"
                                                                                                                                                        : "../common/images/ico_danger_48.png")
            }

            Text
            {
                id: resultMessage

                anchors.top: sign.bottom
                anchors.topMargin: 10
                anchors.horizontalCenter: parent.horizontalCenter

                text: EnumHelper.getKey(context, "sendTroublesState") === "SendStateDone" ? tr.Localize(EnumHelper.getKey(context, "sendTroublesState"))
                                                                                          : (context.errorCode ? tr.Localize(EnumHelper.getKey(context, "errorCode"))
                                                                                                               : tr.Localize(EnumHelper.getKey(context, "errorCode")));
                font: commonFontStyles.standardCommonTextFont
                horizontalAlignment: Text.AlignLeft
            }

            Widgets.DPIScaler { changeHeight: true }

            Timer
            {
                running: resultIndicator.opacity == 1
                interval: 2000

                onTriggered:
                {
                    supportSendTroublesDialog.state = "normalState";
                }
            }

            Behavior on opacity
            {
                NumberAnimation
                {
                    duration: supportSendTroublesDialog.questionOpenTime;
                    easing.type: Easing.InOutQuad
                }
            }
        }

    }

    states:
    [
        State
        {
            name: "questionState"
            PropertyChanges {target: smoothRect; state: "visible"}
            PropertyChanges {target: questionRect; state: "visible"}
            PropertyChanges {target: sendReportColumn; enabled: false}
        },
        State
        {
            name: "srfQuestionState"
            extend: "questionState"
            PropertyChanges {target: srfQuestionColumn; visible: true}
            StateChangeScript {script: srfNumberEditBox.forceActiveFocus()}
        },
        State
        {
            name: "saveToFileQuestionState"
            extend: "questionState"
            PropertyChanges {target: saveToFileColumn; visible: true}
        },
        State
        {
            name: "sendState"
            when: sendState || sendFlag
            extend: "normalState"
            PropertyChanges {target: sendReportColumn; opacity: 0}
        },
        State
        {
            name: "normalState"
            when: true === true
            PropertyChanges {target: smoothRect; state: "hidden"}
            PropertyChanges {target: questionRect; state: "hidden"}
            PropertyChanges {target: srfQuestionColumn; visible: false}
            PropertyChanges {target: saveToFileColumn; visible: false}
        }
    ]
}
