import QtQuick 1.1
import QtWebKit 1.0
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../main_window" as MainFrame

MainFrame.InnerContent
{
	Localizer { id:tr; scope:"MainWindow" }
	caption: tr.Localize("UcpPanel")
	objectName: "ucpWizard"
	id: ucpWizard

	onBack:
	{
		getViewAreaItem().visible = false
	}
 
 	viewArea: Component
	{
		Item
		{
			anchors.fill: parent
			objectName: "ucpPanel"
			property variant context: MainWindow.ucpWizard

			Widgets.BrowserPage
			{
				id: page
				objectName: "ucpBrowser"	

				Component.onCompleted:		context.SetAccessManager(Network);
	
				url:			context.StartUrl;
				anchors.fill:	parent

				property string connectedHandler: ""
				property string failureHandler: ""

				onUrlLoadFailed:
				{
					console.log("ucp::onLoadFailed: " + url);
					showHtml(context.ErrorHtmlUrl);
				}

				Connections 
				{
					target: context;
					onConnected:
					{
						console.log("ucp: " + page.connectedHandler);
						if (page.connectedHandler != "")
							page.browser.evaluateJavaScript(page.connectedHandler + '()');
					}

					onFailure:
					{
						console.log("ucp: " + page.failureHandler);
						if (page.failureHandler != "")
							page.browser.evaluateJavaScript(page.failureHandler + '()');
					}
				}


				js: QtObject
				{
					WebView.windowObjectName: "UCPInteraction"

					function trace(what)
					{
						console.log("ucp portal:" + what);
					}

					function close()
					{
						ucpWizard.back();
					}

					function openUrl(url)
					{
						Window.OpenURL(url);
					}

					function setMyAccountLogin(login)
					{
						context.MyAccountLogin = login;
					}
					function setToken(token)
					{
						if (!context.SetToken(token))
							page.browser.evaluateJavaScript(page.failureHandler + '()');
					}
					function setAccountExpirationDate(date)
					{

					}
					
					function setRegisteredHandler(functionName)
					{
						page.connectedHandler = functionName;
					}
					
					function setRegistrationFailedHandler(functionName)
					{
						page.failureHandler = functionName;
					}

					function openProxySettings()
					{
						context.ShowProxySettings();
					}

					function refresh()
					{
						page.url = context.StartUrl;
					}
				}
			}
		}
	}
}


