import QtQuick 1.1

Item
{
	id: hotKey
	objectName: "HotKey"

	property string text
	signal pressed

	property variant hotKeyIsOn: visible && enabled && (currentScope ? currentScope.hotKeysEnabled : false);
	property variant currentScope: hotKeyScopeFinder.hotKeyScope
	property variant registeredInScope: null
	property string registeredForText: ""

	HotKeyScopeFinder {	id: hotKeyScopeFinder }

	function register()
	{
		if (!currentScope || !hotKeyIsOn || registeredInScope || !text)
			return;
		registeredInScope = currentScope;
		if (currentScope.register(text, pressed))
			registeredForText = text;
		else
			registeredInScope = null;
	}

	function unregister()
	{
		if (!registeredInScope || !registeredForText)
			return;
		registeredInScope.unregister(registeredForText);
		registeredInScope = null;
		registeredForText = "";
	}

	Component.onCompleted: register();
	Component.onDestruction: unregister();
	onHotKeyIsOnChanged: hotKeyIsOn ? register() : unregister();
	onCurrentScopeChanged: { unregister(); register(); }
	onTextChanged: { unregister(); register(); }
}
