import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "SearchListItems.js" as SearchListItems
import "../common/EnumHelper.js" as EnumHelper
import "../common/HelpMapper.js" as HelpMapper

InnerContent
{
    id: searchPanel
    unloadable: false
    property int helpId: HelpMapper.MainWindowSearchHelpId
    Localizer { id: tr; scope: "Search" }
    caption: tr.Localize("SearchResults")

    function updateSearchList(text)
    {
        getViewAreaItem().updateSearchList(text)
    }

    function onShow()
    {
        showSearchBox()
    }
    function onHide()
    {
        hideSearchBox()
    }
    function showSearchBox()
    {
        moveSearch.state="Show"
    }
    function hideSearchBox()
    {
        moveSearch.state="Hide"
    }

    viewArea: Component
    {
        id: searchComponent
        Item
        {
            property variant fontStyles: Fonts.Fonts{}
            property variant commonFontStyles: Fonts.Common{}
            property variant context: MainWindow

            property bool noSearchResults: false

			function checkTextForSearchKeys(datum, text)
			{
				var searchKeys = (tr.Localize(datum.listItem) + (datum.searchKeys ? (" " + tr.Localize(datum.searchKeys)) : "")).toLowerCase();
				if (!searchKeys)
					return;
				var strings = text.toLowerCase().split(" ");
				for (var i = 0; i != strings.length; ++i)
				{
					var searchSubstr = strings[i];
					if (searchKeys.search(searchSubstr) == -1)
						return false;
				}
				return true;
			}
            function updateSearchListFromDataArray(data, text)
            {
                var lastImageSource = (searchListModel.count != 0) ? searchListModel.get(searchListModel.count-1).imageSource : ""
                for (var index in data)
                {
                    var datum = data[index];
                    var itemText = tr.Localize(datum.listItem);
                    if (itemText.length && (text == "*" || checkTextForSearchKeys(datum, text)))
                    {
                        datum.firstInGroup = datum.imageSource != lastImageSource;
                        searchListModel.append(datum);
                        if (datum.firstInGroup)
				lastImageSource = datum.imageSource;
                    }
                }
            }
            function updateSearchList(text)
            {
                searchListModel.clear();
                if (!text || text == "")
                {
                    noSearchResults = false;
                    return;
                }

                updateSearchListFromDataArray(SearchListItems.generalSearchData, text);
                switch(EnumHelper.getKey(context, "productType"))
                {
                    case "KasperskyInternetSecurity":
                    {
                        updateSearchListFromDataArray(SearchListItems.kisSpecificSearchData,text);
                        updateSearchListFromDataArray(SearchListItems.kisSpecificSettingsSearchData,text);
                        break;
                    }
                    case "KasperskyAntiVirus":
                        updateSearchListFromDataArray(SearchListItems.kavSpecificSearchData,text);
                        break;
                }
                updateSearchListFromDataArray(SearchListItems.settingsSearchData, text);
                noSearchResults = searchListModel.count == 0
            }

            Widgets.EmptyListText
            {
                visible: noSearchResults
                text: tr.Localize("EmptySearchResults")
            }

            Item
            {
                id: searchlist
                anchors.fill: parent
                visible: searchListView.count > 0

                ListModel
                {
                        id: searchListModel
                }

                ListView
                {
                        id: searchListView
                        anchors.fill: parent
                        model : searchListModel
               			property int tabOrder: 1
                        interactive: true

                        clip: true
                        delegate : Item
                        {
                                id: row
                                height: 60
                                width: parent.width
								focus: searchListView.currentIndex == index && enabled
                                Item
                                {
                                    clip: !firstInGroup
                                    anchors.fill: parent
                                    anchors.leftMargin: verticalSeparator.x
                                    Image
                                    {
                                        anchors.left: parent.left
                                        anchors.leftMargin: -parent.anchors.leftMargin
                                        source: "../common/images/inner/list_separator.png"
                                        anchors.top: parent.top
                                        width: parent.width - anchors.leftMargin
                                        mirror: Window.Mirror
                                    }
                                }
                                Image
                                {
                                    id: imageSearchItem
                                    anchors.left: parent.left
                                    anchors.leftMargin: 10
                                    anchors.verticalCenter: parent.verticalCenter
                                    source: imageSource
                                    visible: firstInGroup
                                }

                                Rectangle
                                {
                                    id: verticalSeparator
                                    height: parent.height
                                    width: 1
                                    color: "#dddddd"
                                    anchors.left: imageSearchItem.right
                                    anchors.leftMargin: 10
                                }

                                Text
                                {
                                    text: tr.Localize(listItem)
                                    anchors.left: verticalSeparator.right
                                    anchors.verticalCenter: parent.verticalCenter
                                    font: commonFontStyles.standardSmallCaptionFont
                                    anchors.leftMargin: 10
                                    horizontalAlignment: Text.AlignLeft

                                    Widgets.FocusRect{target: row}
                                }

							    Keys.onSpacePressed: row.onClicked()
							    Keys.onReturnPressed: row.onClicked()
							    Keys.onEnterPressed: row.onClicked()

								function onClicked()
								{
                                	if (panel != undefined)
                                        searchPanel.activate(panel)
                                    else if (oldAction != undefined)
                                        MainWindow.InvokeSkinAction(oldAction);
								}
                                MouseArea
                                {
                                        anchors.fill: row
                                        hoverEnabled:	parent.enabled
                                        onClicked:
                                        {
                                        	row.onClicked();
                                        }

								        onPressed:
								        {
											if (!row.activeFocus)
												searchListView.currentIndex = index;
											if (!searchListView.activeFocus)
												searchListView.forceActiveFocus();
								        }
                                        Widgets.Clickable {}
                                }
                        }

                        footer: Image
                        {
                            source: "../common/images/inner/list_separator.png"
                            width: parent.width
                            mirror: Window.Mirror
                        }
                }

                Widgets.ScrollBar
                {
                    target: searchListView
                    height: searchListView.height
                    anchors
                    {
                        verticalCenter: searchListView.verticalCenter
                        right: parent.right
                    }
                }

            }
        }
    }
}



