import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "CompatibilityPage"

    property int helpId: HelpMapper.CompatibilitySettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Compatibility")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "CompatibilitySettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "CompatibilityGeneralSection"
            body: Column
            {
                objectName: "CompatibilityGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "ApplySpecialTreatmentColumn"
                    width: parent.width
                    spacing: Margins.settingsSectionInnerSpacing

                    SettingsCommon.CheckBox
                    {
                        id: applySpecialTreatment
                        objectName: "ApplySpecialTreatment"
                        anchors.left: parent.left
                        text: tr.Localize("ApplySpecialTreatment");
                        isBold: true

                        target: context
                        property: "useAv"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        anchors.leftMargin: applySpecialTreatment.textMargin
                        width: parent.width - anchors.leftMargin
                        text: tr.Localize("ApplySpecialTreatmentDescription")
                        wrapMode: Text.Wrap
                    }

                    Row
                    {
                        spacing: 7
                        width: parent.width
                        anchors.left: parent.left
                        anchors.leftMargin: applySpecialTreatment.textMargin

                        Image
                        {
                            id: warning
                            source: "../../common/images/ico_warning_16.png"
                            mirror: Window.Mirror
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            width: parent.width - warning.width - parent.anchors.leftMargin
                            text: tr.Localize("ApplySpecialTreatmentWarning")
                            wrapMode: Text.Wrap
                        }
                    }
                }
                Column
                {
                    objectName: "EnableStartupDelayColumn"
                    spacing: Margins.settingsSectionInnerSpacing
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: enableStartupDelay
                        objectName: "EnableStartupDelay"
                        anchors.left: parent.left
                        text: tr.Localize("EnableStartupDelay");
                        isBold: true

                        target: context
                        property: "enableAutoStartupDelay"

                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        anchors.leftMargin: enableStartupDelay.textMargin
                        width: parent.width - enableStartupDelay.textMargin
                        text: tr.Localize("EnableStartupDelayDescription")
                        wrapMode: Text.Wrap
                    }
                }
                Column
                {
                    objectName: "LetOthersTakeColumn"
                    spacing: Margins.settingsSectionInnerSpacing
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: letOthersTake
                        objectName: "LetOthersTake"
                        anchors.left: parent.left
                        text: tr.Localize("LetOthersTake");
                        isBold: true

                        target: context
                        property: "useAbs"

                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        anchors.leftMargin: letOthersTake.textMargin
                        width: parent.width - letOthersTake.textMargin
                        text: tr.Localize("LetOthersTakeDescription")
                        wrapMode: Text.Wrap
                    }
                }
            }
        }
    }
}
