import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper


Item
{
    id: settingsPage
    objectName: "SafeBankingSettingsPage"

    property string helpUrl: "$HelpURLSettingsOnlineBanking"
    property int helpId: HelpMapper.SafeBankingSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "SafeBanking")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "SafeBankingSettings" }

    Column
    {
        id: safeBankingColumn
        objectName: "SafeBankingColumn"

        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            id: safeBankingEnabled
            objectName: "SafeBankingEnabled"
            body: Column
            {
                objectName: "SafeBankingEnabledColumn"
                spacing: Margins.settingsMainSectionSpacing - (createShortcutButton.height - safeBankingEnabledCheckBox.height)/2

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                Item
                {
                    objectName: "CreateShortcutRow"

                    anchors.left: parent.left
                    anchors.right: parent.right
                    height: createShortcutButton.height

                    SettingsCommon.CheckBox
                    {
                        id: safeBankingEnabledCheckBox
                        anchors.left: parent.left
                        isBold: true

                        objectName: "SafeBankingEnabledCheckBox"

                        anchors.verticalCenter: parent.verticalCenter

                        text: tr.Localize("EnableSafeBanking");
                        target: context
                        property: "safeBankingEnabled"
                    }

                    Widgets.GrayButton
                    {
                        id: createShortcutButton

                        anchors.right: parent.right

                        objectName: "CreateShortcutButton"
                        text: tr.Localize("CreateShortcut")
                        onClicked:
                        {
                            context.CreateShortcut()
                        }
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "BehaviourRulesSection"
            body: Item
            {
                id: behaviorRulesColumn
                objectName: "BehaviourRulesColumn"
                height: settingsPage.height - safeBankingEnabled.height - safeBankingColumn.spacing - 30
                width: parent.width

                Item
                {
                    id: behaviorRulesWrapper
                    anchors.top: parent.top
                    anchors.bottom: notificationsWrapper.top
                    anchors.bottomMargin: Margins.settingsInnerSpacing
                    objectName: "BehaviourRulesWrapper"
                    width: parent.width

                    SettingsCommon.SettingsStandardText
                    {
                        id: behaviorRules
                        anchors.top: parent.top
                        anchors.left: parent.left
                        isBold: true
                        text: tr.Localize("BehaviourRules")
                        wrapMode: Text.Wrap
                        color: context.safeBankingEnabled ? "black" : "grey"
                    }

                    SafeBankingBehaviourRules
                    {
                        id: behaviourRulesItem

                        anchors.top: behaviorRules.bottom
                        anchors.topMargin: Margins.settingsAfterTextSpacing
                        anchors.bottom: parent.bottom
                        enabled: context.safeBankingEnabled
                    }

                }

                Column
                {
                    id: notificationsWrapper
                    objectName: "NotificationsWrapper"
                    anchors.bottom: parent.bottom
                    spacing: Margins.settingsSectionInnerSpacing
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: osVulnerabilityNotifications
                        objectName: "OperationSystemVulnerabilityNotifications"
                        isBold: true
                        anchors.left: parent.left

                        enabled: context.safeBankingEnabled
                        text: tr.Localize("OperationSystemVulnerabilityNotifications");
                        target: context
                        property: "osVulnerabilityNotificationsEnabled"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        id: footerText

                        width: parent.width
                        anchors.left: parent.left
                        text: tr.Localize("Footer")
                        wrapMode: Text.Wrap
                        color: context.safeBankingEnabled ? "black" : "grey"
                    }
                }
            }
        }
    }
}
