import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    objectName: "ScanGeneralSettingsPage"

    property int helpId: HelpMapper.ScanGeneralSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "ScanGeneral")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "ScanGeneralSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "IdleScan"
            name: tr.Localize("IdleScan")
            smallTopMargin: true
            smallBottomMargin: true
            body: Column
            {
                spacing: Margins.settingsSectionInnerSpacing
                width: parent.width


                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                    horizontalAlignment: Text.AlignLeft
                }

                Column
                {
                    anchors.left: parent.left
                    height: childrenRect.height
                    objectName: "EnableScanWrapper"
                    spacing: Margins.settingsCheckboxSpacing

                    Row
                    {
                        objectName: "EnableIdleScanWrapper"
                        width: enableIdleScanId.width
                        spacing: -5

                        SettingsCommon.CheckBox
                        {
                            id: enableIdleScanId
                            objectName: "EnableIdleScan"
                            text: tr.Localize("EnableIdleScan")
                            target: context
                            property: "enableIdleScan"
                            maxWidth: 1000000
                        }

                        Item
                        {
                            objectName: "HelpSettingsIdleScanWrapper"
                            height: parent.height
                            width: childrenRect.width

                            Widgets.InfoLink
                            {
                                objectName: "HelpSettingsIdleScan"
                                anchors.verticalCenter: parent.verticalCenter
                                anchors.verticalCenterOffset: 1
                                url: "$HelpURLSettingsIdleScan"
                            }
                        }
                    }

                    SettingsCommon.CheckBox
                    {
                        objectName: "EnableQscan"
                        text: tr.Localize("EnableQscan")

                        target: context
                        property: "enableQscan"
                        anchors.left: parent.left
						maxWidth: 1000000
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "RemovableDisksAutoScanSection"
            name: tr.Localize("RemovableDisksAutoScan")

            body: Column
            {
                objectName: "RemovableDisksAutoScan"
                width: parent.width
                spacing: Margins.settingsRadioSpacing

                SettingsCommon.EnumRadioGroup
                {
                    objectName: "removableDisksAutoScanMode"
                    target: context
                    property: "removableDisksAutoScanMode"
                    localizer: tr
                    spacing: Margins.settingsSectionInnerSpacing
                    anchors.left: parent.left
                }

                Item
                {
                    objectName: "AutoScanCheckSizeWrapper"
                    width: parent.width;
                    height: childrenRect.height;

                    SettingsCommon.CheckBox
                    {
                        id: autoScanCheckSize
                        objectName: "AutoScanCheckSize"
                        text: tr.Localize("AutoScanCheckSize")
                        height: autoScanMaxSize.height
                        target: context
                        property: "autoScanCheckSize"
                        enabled: context.enableAutoScanCheckSize
                        anchors.left: parent.left
                    }

                    Widgets.IntSpinEdit
                    {
                        id: autoScanMaxSize
                        objectName: "AutoScanMaxSize"

                        anchors.left: autoScanCheckSize.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: autoScanCheckSize.verticalCenter
                        anchors.verticalCenterOffset: 2
                        target: context
                        property: "autoScanMaxSize"
                        enabled: context.enableAutoScanCheckSize && context.autoScanCheckSize
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        id: mb;
                        anchors.left: autoScanMaxSize.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: autoScanMaxSize.verticalCenter
                        text: tr.Localize("MB")
                        color: context.enableAutoScanCheckSize && context.autoScanCheckSize ? "black" : "grey"
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "CreateShortcutsSection"
            name: tr.Localize("CreateShortcuts")
            smallTopMargin: true
            smallBottomMargin: true

            body: Column
            {
                objectName: "CreateShortcutsColumn"
                spacing: Margins.settingsSectionInnerSpacing
                width: parent.width

                CreateShortCutRow
                {
                    objectName: "FullScan";
                    labelText: tr.Localize("FullScan");
                    buttonText: tr.Localize("FullScanCreateShortcut");
                    onClicked: context.CreateFullScanShortCut();
                    width: parent.width
                }

                CreateShortCutRow
                {
                    objectName: "CriticalAreaScan";
                    labelText: tr.Localize("CriticalAreaScan");
                    buttonText: tr.Localize("CriricalAreaScanCreateShortcut");
                    onClicked: context.CreateCriticalAreaScanShortCut();
                    width: parent.width
                }

                CreateShortCutRow
                {
                    objectName: "VulnerabilityScan";
                    labelText: tr.Localize("VulnerabilityScan");
                    buttonText: tr.Localize("VulnerabilityScanCreateShortcut");
                    onClicked: context.CreateVulnerabilityScanShortCut();
                }
            }
        }
    }
}
