import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/Colors.js" as Colors
import "../common/HelpMapper.js" as HelpMapper
import "../common/fonts" as Fonts

Border.BorderedContent
{
    content: support

    property variant commonFontStyles: Fonts.Common{}

    Widgets.SecondaryWindow
    {
        id: support

        property int helpId: HelpMapper.SupportMainHelpId

        objectName: "support"
        width: 550
        height: 490
        Localizer { id: tr; scope: "Support" }
        caption: tr.Localize("Caption");

        workArea: Item
        {
            id: mainArea;
            objectName: "WorkArea"

            anchors.fill: parent

            Widgets.DPIScaler
            {
                id: dpiScaler
                changeHeight: true
                changeWidth: true
            }

            SupportMain
            {
                id: supportMain

                x: 0
                width: parent.width
                anchors.top: parent.top
                anchors.bottom: parent.bottom

                onMonitoring:
                {
                    animation.show(supportMain, supportMonitoring, false)
                }
                onVisibleChanged:
                {
                    if(visible)
                        support.helpId = HelpMapper.SupportMainHelpId
                }
            }


            SupportSendTroublesDialog
            {
                id: supportSendTroublesDialog
                visible: false

                x: 0
                width: parent.width
                anchors.top: parent.top
                anchors.bottom: parent.bottom

                onMonitoring:
                {
                    animation.show(supportSendTroublesDialog, supportMonitoring, true)
                }

                onMain:
                {
                    animation.show(supportSendTroublesDialog, supportMain, true)
                }

                onFilesList:
                {
                    animation.show(supportSendTroublesDialog, supportReportFilesList, false)
                }
                onVisibleChanged:
                {
                    if(visible)
                        support.helpId = HelpMapper.SupportSendTroublesHelpId
                }
            }

            SupportReportFilesList
            {
                id: supportReportFilesList
                visible: false

                x: 0
                width: parent.width
                anchors.top: parent.top
                anchors.bottom: parent.bottom

                onMain:
                {
                    animation.show(supportReportFilesList, supportMain, true)
                }
                onSendReport:
                {
                    animation.show(supportReportFilesList, supportSendTroublesDialog, true)
                }
                onVisibleChanged:
                {
                    if(visible)
                        support.helpId = HelpMapper.SupportReportFilesHelpId
                }
            }

            SupportMonitoring
            {
                id: supportMonitoring
                visible: false

                x: 0
                width: parent.width
                anchors.top: parent.top
                anchors.bottom: parent.bottom

                onMain:
                {
                    animation.show(supportMonitoring, supportMain, true)
                }

                onSendReport:
                {
                    animation.show(supportMonitoring, supportSendTroublesDialog, false)
                }
                onVisibleChanged:
                {
                    if(visible)
                        support.helpId = HelpMapper.SupportMonitoringHelpId
                }
            }

            SequentialAnimation
            {
                id: animation
                property alias oldPanel: oldPanelAnimation.target
                property alias newPanel: newPanelAnimation.target
                property bool isBackDirection: false
                property int velocity: 1200

                function show(newPanel, oldPanel, back)
                {
                    isBackDirection = back
                    animation.oldPanel = newPanel
                    animation.newPanel = oldPanel
                    animation.running = true
                }

                ScriptAction
                {
                    script:
                    {
                        animation.newPanel.x = (Window.Mirror ? -1 : 1) * (animation.isBackDirection ? -1 : 1) * mainArea.width
                        support.hotKeysEnabled = false;
                        animation.newPanel.visible = true
                    }
                }

                ParallelAnimation
                {
                    SmoothedAnimation
                    {
                        id: oldPanelAnimation
                        property: "x";
                        to: (Window.Mirror ? 1 : -1) * (animation.isBackDirection ? -1 : 1) * (target ? target.width : 0)
                        velocity: animation.velocity
                    }
                    SmoothedAnimation
                    {
                        id: newPanelAnimation
                        property: "x";
                        to: 0;
                        velocity: animation.velocity
                    }
                }
                ScriptAction
                {
                    script:
                    {
                        animation.oldPanel.visible = false
                        support.hotKeysEnabled = true;
                    }
                }
            }
        }

        buttonsArea: FocusScope
        {
            id: bottomRow
            anchors.fill: parent
            objectName: "bottom"
            property int tabOrder: 2


            Widgets.HelpButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    leftMargin: 12
                }

                objectName: "help"
                text: tr.Localize("Help")
                onClicked: Help.Show(support.helpId)
            }

            function applyAndChangePageIfNeeded()
            {
                var invalidPage = Settings.Apply();
                if (invalidPage !== "")
                {
                    settings.showPage(invalidPage)
                    return false;
                }
                return !Settings.hasChanges;
            }

            Widgets.GrayButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }

                objectName: "close"
                text: tr.Localize("CloseButton")
                onClicked: Window.Close()
            }
        }

        Widgets.DPIScaler {
            id: dpiScaler
            changeHeight: true
        }
    }
}
